@@ -6,12 +6,17 @@ from pydm.widgets.channel import PyDMChannel
 from qtpy import QtCore, QtWidgets, uic
 
 from . import utils, widgets
+from .alarm import KindLevel, _KindLevel
 from .status import TyphosStatusThread
 
 logger = logging.getLogger(__name__)
 
 
-class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
+class TyphosPositionerWidget(
+    utils.TyphosBase,
+    widgets.TyphosDesignerMixin,
+    _KindLevel,
+):
     """
     Widget to interact with a :class:`ophyd.Positioner`.
 
@@ -73,6 +78,8 @@ class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
                    ``hinted`` signals.
     ============== ===========================================================
     """
+    QtCore.Q_ENUMS(_KindLevel)
+    KindLevel = KindLevel
 
     ui_template = os.path.join(utils.ui_dir, 'widgets', 'positioner.ui')
     _readback_attr = 'user_readback'
@@ -168,9 +175,15 @@ class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
             timeout = None
         logger.debug("Setting device %r to %r with timeout %r",
                      self.device, value, timeout)
-        # Send timeout through thread because status timeout stops the move
-        status = self.device.set(set_position)
-        self._start_status_thread(status, timeout)
+        try:
+            status = self.device.set(set_position)
+        except Exception as exc:
+            # Treat this exception as a status to use normal error reporting
+            # Usually this is e.g. limits error
+            self._status_finished(exc)
+        else:
+            # Send timeout through thread because status timeout stops the move
+            self._start_status_thread(status, timeout)
 
     @QtCore.Slot(int)
     def combo_set(self, index):
@@ -569,6 +582,15 @@ class TyphosPositionerWidget(utils.TyphosBase, widgets.TyphosDesignerMixin):
         else:
             self.ui.expert_button.hide()
 
+    @QtCore.Property(_KindLevel, designable=True)
+    def alarmKindLevel(self) -> KindLevel:
+        return self.ui.alarm_circle.kindLevel
+
+    @alarmKindLevel.setter
+    def alarmKindLevel(self, kind_level: KindLevel):
+        if kind_level != self.alarmKindLevel:
+            self.ui.alarm_circle.kindLevel = kind_level
+
     def move_changed(self):
         """Called when a move is begun"""
         logger.debug("Begin showing move in TyphosPositionerWidget")
